@@ -417,10 +417,10 @@ def transformVerb(verb,format_set):
         if engine_name == SegmentationEngine.JANOME:
             words = [ token.surface for token in engine.tokenize(verb)]
         if engine_name == SegmentationEngine.JUMAN:
-            words = [ mrph.genkei for mrph in engine.analysis(verb).mrph_list()]
+            words = [ mrph.midasi for mrph in engine.analysis(verb).mrph_list()]
 
         if words is not None:
-            verb = "".join(words)
+            # verb = "".join(words)
             if words[-1] in kotodama_dic:
                 values = kotodama_dic[words[-1]]
             elif words[-1]+"だ" in kotodama_dic:
@@ -443,9 +443,13 @@ def transformVerb(verb,format_set):
     # 特定の数の多い用言に関してはendswithを許す
     if values == None:
         if verb.endswith("ある"):
+            values = ["ある","動詞","子音動詞ラ行"]
+
+        if verb.endswith("いる"):
+            values = ["いる","動詞","母音動詞"]
+
             # 最後が「だ」で終わるものはほとんどナ形容詞
             # 一部の例外は辞書で事前にカバーする
-            values = ["ある","動詞","子音動詞ラ行"]
         if verb.endswith("だ"):
             # 最後が「い」で終わるものはほとんどい形容詞
             # イ形容詞イ段とイ形容詞アウオ段の違いはここでは特に必要ではない
@@ -456,8 +460,6 @@ def transformVerb(verb,format_set):
     if values == None:
         raise ValueError("辞書に定義されていない単語%sが入力されました。kotodama_dic.csvに「%s」を追加してください" %(str(words),str(verb)))
 
-    print(values)
-
     target_verb = values[0]
     hinsi = values[1]
     katuyou1 = values[2]
